package protocol

import (
	"time"
)

type PacketType int

const (
	ReqPK PacketType = iota
	ReqAllMsg
	ReqMsg
    SubmitMsg
	SendPK
    Msg
)

type PacketBody interface {}

type Packet struct {
	Flag PacketType
	Body PacketBody
}

// Client --> Server: Ask for a user's public key
type RequestPubKey struct {
	FromUID string
	KeyUID  string
}

// Client --> Server: Ask for all the client's messages in the queue
type RequestAllMsg struct {
	FromUID string
}

// Client --> Server: Ask for a specific message in the queue
type RequestMsg struct {
	Num     uint16
}

// Client --> Server: Send message from client to server 
type SubmitMessage struct {
	ToUID   string
	Subject []byte
	Body    []byte
}

// Server --> Client: Send the client the requested public key
type SendPubKey struct {
	Key     []byte
}

// Server --> Client: Send the client a message
type Message struct {
    FromUID string
	ToUID   string
	Subject []byte
	Body    []byte
    Timestamp time.Time
}
